###################################################
library("HPLCDAD")

###################################################
source("alprazolam.R")


###################################################
par(mfrow=c(1,2),mar=c(3,3,1,1),mgp=c(2,.8,0))
plot(time0,chrom0,type="l")
plot(lambda0,spec0,type="l")
lines(lambda0,spec1,lty=2,col=2)


###################################################
sim0<-Simul.DAD(resol=0,
                chrom=chrom0,
                prin.spec=spec0,
                wavelengths=lambda0,
                times=time0,
                timeunit="min",
                wavelengthunit="nm",
                hetero=3,
                std.err=rep(0.00003,length(lambda0)))
par(mfrow=c(1,1),mar=c(3,3,1,1),mgp=c(2,.8,0))
plot(PeakPurity(sim0,verbose=FALSE))


###################################################
sim0i<-Simul.DAD(resol=0.8,
                 chrom=chrom0,
                 prin.spec=spec0,
                 impur.spec=spec1,
                 wavelengths=lambda0,
                 timeunit="min",
                 wavelengthunit="nm",
                 conc=0.004,
                 times=time0,
                 hetero=3,
                 scanrate=0,
                 std.err=rep(0.00003,length(lambda0)))
par(mfrow=c(1,1),mar=c(3,3,1,1),mgp=c(2,.8,0))
plot(PeakPurity(sim0i,verbose=FALSE))


###################################################
Specsim(PeakPurity(sim0i,bilinear.model="peel"),
        PeakPurity(sim0,bilinear.model="peel"))


###################################################
al1<-Read.DAD("al1.txt")


###################################################
par(mfrow=c(1,1),mar=c(3,3,1,1),mgp=c(2,.8,0))
plot(PeakPurity(al1,verbose=FALSE))


###################################################
al1ta<-PeakPurity(Treat.DAD(al1),bilinear.model="peel")
simal1t<-Simul.DAD(resol=0,
                   chrom=al1ta@ct[,1],
                   UAmax=max(al1ta@ct[,1]),
                   prin.spec=al1ta@spec[,1],
                   times=al1ta@time,timeunit=al1ta@timeunit,
                   std.err=al1ta@std.err,hetero=al1ta@hetero,
                   wavelengths=al1ta@wavelength,wavelengthunit=al1ta@wavelengthunit,
                   ncanal=4,scanrate=1/16,
                   make.cross=TRUE, bit.loss=6
                   )
simal1ta<-PeakPurity(Treat.DAD(simal1t),bilinear.model="peel",verbose=FALSE)
par(mfrow=c(1,2),mar=c(3,3,1,1),mgp=c(2,.8,0))
image(al1ta@data-predict(al1ta,level=1)); image(simal1ta@data-predict(simal1ta,level=1))


###################################################
Specsim(al1ta,simal1ta)


###################################################
## obtain shifted chromatogram for impurity
impur.chrom <- 
  exp(approx(al1ta@time, 
             log(al1ta@ct[,1] + 0.001), 
                 xout = al1ta@time - FWHM(al1ta@ct[,1],al1ta@time) *1)$y )-.001
impur.chrom[is.na(impur.chrom)]<-0
## create spectrochromatogram for impurity and size it
impur<-tcrossprod(impur.chrom,spec1)
impur<-impur/max(impur)*0.005*max(al1ta@data)
## add it to the real data
al1i<-al1
al1i@data<-al1@data+impur
## analyze it and show the result
al1ita<-PeakPurity(Treat.DAD(al1i),bilinear.model="peel",verbose=FALSE)
plot(al1ita)


###################################################
simal1it<-Simul.DAD(resol=0,
                   chrom=al1ita@ct[,1],
                   UAmax=max(al1ita@ct[,1]),
                   prin.spec=al1ita@spec[,1],
                   times=al1ita@time,timeunit=al1ita@timeunit,
                   std.err=al1ita@std.err,hetero=al1ita@hetero,
                   wavelengths=al1ita@wavelength,wavelengthunit=al1ita@wavelengthunit,
                   ncanal=4,scanrate=1/16,
                   make.cross=TRUE, bit.loss=6
                   )
simal1ita<-PeakPurity(Treat.DAD(simal1it),bilinear.model="peel",verbose=FALSE)
Specsim(al1ita,simal1ita)
